;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gleam-ts-mode" "20251006.1500"
  "Major mode for Gleam."
  '((emacs "29.1"))
  :url "https://github.com/gleam-lang/gleam-mode"
  :commit "bd4a0ea995cab2bd2676d04ff155eccd306f835d"
  :revdesc "bd4a0ea995ca"
  :keywords '("languages" "gleam"))
